@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <float.h>
 #include "map.h"
 
@@ -94,6 +95,7 @@ Polyline r[];
 	rh->sw.y = ymin;
 	rh->ne.x = xmax;
 	rh->ne.y = ymax;
+/*	printf("%f12 %f12 %f12 %f12\n", xmin, ymin, xmax, ymax); */
 }
 
 struct line_h *
